@@ -1,6 +1,6 @@
 package Net::Bullfinch;
 {
-  $Net::Bullfinch::VERSION = '0.03';
+  $Net::Bullfinch::VERSION = '0.04';
 }
 use Moose;
 use MooseX::Params::Validate;
@@ -10,20 +10,19 @@ use MooseX::Types::DateTime;
 
 use Data::UUID;
 use JSON::XS;
-use Net::Kestrel;
+use Memcached::Client;
 
 use Net::Bullfinch::Iterator;
 
 
 has '_client' => (
     is => 'rw',
-    isa => 'Net::Kestrel',
+    isa => 'Memcached::Client',
     default => sub {
         my $self = shift;
-        return Net::Kestrel->new(
-            host => $self->host,
-            ($self->port ? (port => $self->port) : ())
-        );
+        return Memcached::Client->new ({
+            servers => [ $self->host.':'.$self->port ]
+        });
     },
     lazy => 1
 );
@@ -36,7 +35,8 @@ has 'host' => (
 
 has 'port' => (
     is => 'rw',
-    isa => 'Int'
+    isa => 'Int',
+    default => '22133'
 );
 
 has 'response_prefix' => (
@@ -64,13 +64,14 @@ sub send {
     my ($rname, $json) = $self->_prepare_request($data, $queuename, $trace, $procby);
     my $kes = $self->_client;
 
-    $kes->put($queue, $json);
+    $kes->set($queue, $json);
 
     my @items = ();
     while(1) {
-        my $resp = $kes->get($rname, $self->timeout);
+        #my $resp = $kes->get($rname, $self->timeout);
+        my $resp = $kes->get($rname.'/t='.$self->timeout.'/open');
         if(defined($resp)) {
-            $kes->confirm($rname, 1);
+            $kes->get($rname.'/close');
             my $decoded = decode_json($resp);
             if(exists($decoded->{EOF})) {
                 last;
@@ -98,7 +99,7 @@ sub iterate {
     my ($rname, $json) = $self->_prepare_request($data, $queuename);
     my $kes = $self->_client;
 
-    $kes->put($queue, $json);
+    $kes->set($queue, $json);
 
     Net::Bullfinch::Iterator->new(
         bullfinch      => $self,
@@ -144,7 +145,7 @@ Net::Bullfinch - Perl wrapper for talking with Bullfinch
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -163,7 +164,7 @@ version 0.03
 
 =head1 DESCRIPTION
 
-Net::Bullfinch is a thin wrapper around <Net::Kestrel> for communicating with
+Net::Bullfinch is a thin wrapper around L<Memcached::Client> for communicating with
 a L<Bullfinch|https://github.com/gphat/bullfinch/>.
 
 This module handles JSON encoding of the request, the addition of a response
